@@ -12,13 +12,11 @@ function (p, x)
  # compute covariance matrix
  VV<- vs*outer(x$tt, x$tt, FUN=pmin)
  diag(VV)<- diag(VV) + x$vv/x$nn 
- detV<- det(VV)
- invV<- solve(VV)
  
  # compute logL based on multivariate normal
  M<- rep(anc, n) + ms*x$tt
- S<- -0.5*log(detV) - 0.5*n*log(2*pi) - ( t(x$mm-M)%*%invV%*%(x$mm-M) ) / (2)
+ #S<- -0.5*log(detV) - 0.5*n*log(2*pi) - ( t(x$mm-M)%*%invV%*%(x$mm-M) ) / (2)
+ S<- dmvnorm(x$mm, mean=M, sigma=VV, log=TRUE)
  
  return(S)		
 }
-
