@@ -18,14 +18,9 @@ function (x, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
  if (meth=="L-BFGS-B")	w<- optim(p0, fn=logL.joint.GRW, control=cl, method=meth, lower=c(NA,NA,0), hessian=hess, x=x)
  else 					w<- optim(p0, fn=logL.joint.GRW, control=cl, method=meth, hessian=hess, x=x)
 
- w$p0<- p0
- w$K<- 3
- w$n<- length(x$mm)
- w$AIC <- IC(w, meth="AIC")
- w$AICc<- IC(w, meth="AICc")
- w$BIC <- IC(w, meth="BIC")
- if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian))) 
-
- return(w)		
+ if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian)))
+ else			w$se<- NULL
+ wc<- as.paleoTSfit(logL=w$value, parameters=w$par, modelName='GRW', method='Joint', K=3, n=length(x$mm), se=w$se)
+  
+ return (wc)
 }
-
