@@ -17,14 +17,9 @@ function (x, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
  if (meth=="L-BFGS-B")	w<- optim(p0, fn=logL.joint.URW, control=cl, method=meth, lower=c(NA,0), hessian=hess, x=x)
  else					w<- optim(p0, fn=logL.joint.URW, control=cl, method=meth, hessian=hess, x=x)
 
- w$p0<- p0
- w$K<- 2
- w$n<- length(x$mm)
- w$AIC <- IC(w, meth="AIC")
- w$AICc<- IC(w, meth="AICc")
- w$BIC <- IC(w, meth="BIC")
- if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian))) 
+ if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian)))
+ else			w$se<- NULL
+ wc<- as.paleoTSfit(logL=w$value, parameters=w$par, modelName='URW', method='Joint', K=2, n=length(x$mm), se=w$se)
   
- return(w)		
+ return (wc)
 }
-
