@@ -9,6 +9,7 @@ function(y, gg, cl=list(fnscale=-1), pool=TRUE, meth="L-BFGS-B", hess=FALSE, osh
   pn<- paste("theta", 1:ng, sep="")
   if(oshare)		{ p0<- c(mg, mean(mv)); K<- 2*ng; pn<- c(pn, "omega")}
   else				{ p0 <- c(mg, mv); K <- 3*ng-1; pn<- c(pn, paste("omega", 1:ng, sep=""))}
+  names(p0)<- pn
   
   cl$ndeps <- p0/100
   if (oshare)
@@ -24,13 +25,8 @@ function(y, gg, cl=list(fnscale=-1), pool=TRUE, meth="L-BFGS-B", hess=FALSE, osh
   
   # add more information to results
   if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian)))
-  names(w$par)<- names(p0)<- pn
-  w$p0 <- p0
-  w$K <- K
-  w$n <- length(y$mm) - 1
-  w$AIC<- IC(w, meth="AIC")
-  w$AICc<- IC(w, meth="AICc")
-  w$BIC<- IC(w, meth="BIC")
-  return(w)
-}
+  else			w$se<- NULL
+  wc<- as.paleoTSfit(logL=w$value, parameters=w$par, modelName=paste('Punc', ng-1, sep='-'), method='AD', K=K, n=length(y$mm)-1, se=w$se)
 
+  return(wc)
+}
