@@ -20,7 +20,8 @@ function(y,gg,cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE, oshare=TRUE, mod
  	}
  
  cl$ndeps <- p0/100
- #cat (p0, "\n")
+ names(p0)<- pn
+
  if (oshare)
   {
    if (meth == "L-BFGS-B") w <- optim(p0, fn=logL.sgs.omega, gg=gg, method=meth, lower=lw, control=cl, hessian=hess, y=y, model=model)
@@ -34,14 +35,8 @@ function(y,gg,cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE, oshare=TRUE, mod
 
   # add more information to results
   if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian)))
-  names(w$par)<- names(p0)<- pn
-  w$p0 <- p0
-  w$K <- K
-  w$n <- length(y$mm) - 1
-  w$AIC<- IC(w, meth="AIC")
-  w$AICc<- IC(w, meth="AICc")
-  w$BIC<- IC(w, meth="BIC")
+  else 			w$se<- NULL
 
-  return(w) 
+  wc<- as.paleoTSfit(logL=w$value, parameters=w$par, modelName=paste('SGS', model, sep='-'), method='AD', K=K, n=length(y$mm)-1, se=w$se)  
+  return(wc) 
 }
-
