@@ -5,7 +5,10 @@ function(y,nn=NULL, ret.paleoTS=FALSE)
 {
  # check if y is a paleoTS object
  if (class(y)=="paleoTS")
-    vp<- sum(y$vv*(y$nn-1))/sum(y$nn-1)
+  {
+    if (all(y$nn==1)) 	vp<- mean(y$vv)
+    else    vp<- sum(y$vv*(y$nn-1))/sum(y$nn-1)
+  }
  else
     vp<- sum(y*(nn-1))/sum(nn-1)
     
@@ -17,4 +20,3 @@ function(y,nn=NULL, ret.paleoTS=FALSE)
  }
  else { return (vp)}
 }
-
