@@ -1,5 +1,5 @@
 sim.GRW <-
-function (ns=20, ms=0, vs=0.1, vp=1, nn=rep(20,ns), tt=1:ns)
+function (ns=20, ms=0, vs=0.1, vp=1, nn=rep(20,ns), tt=0:(ns-1))
 # simulates GRW; ns= number of samples, ms=mean and vs=variance of the step distribution,
 #  vp=population variance, tt=ages of the samples
 {
@@ -20,4 +20,3 @@ function (ns=20, ms=0, vs=0.1, vp=1, nn=rep(20,ns), tt=1:ns)
  res<- as.paleoTS(mm=mm, vv=vv, nn=nn, tt=tt, MM=MM, genpars=gp, label="Created by sim.GRW()") 
  return(res)
 }
-
