@@ -1,5 +1,5 @@
 sim.OU <-
-function (ns=20, anc=0, theta=10, alpha=0.3, vs=0.1, vp=1, nn=rep(20, ns), tt=1:ns)
+function (ns=20, anc=0, theta=10, alpha=0.3, vs=0.1, vp=1, nn=rep(20, ns), tt=0:(ns-1))
 ## generate a paleoTS sequence according to an OU model
 {
     
@@ -27,4 +27,3 @@ function (ns=20, anc=0, theta=10, alpha=0.3, vs=0.1, vp=1, nn=rep(20, ns), tt=1:
 
     return(res)
 }
-
